@@ -65,6 +65,7 @@ class JSON2EDCLineageFiles:
                 self.schema_directory = data["schema_directory"]
                 self.json_directory = data["json_directory"]
                 self.output_directory = data["output_directory"]
+                self.resource_items = data["resource_items"]
         except FileNotFoundError or IOError as e:
             result = messages.message["main_config_not_found"]
             result["info"] = "configuration file used: >%s<" % configuration_file
@@ -120,18 +121,40 @@ class JSON2EDCLineageFiles:
         if src_ref is None:
             src_path = "NONE://" + source_name
         else:
-            src_edc_datasource = src_ref["src_zone"].split("/", 4)[2]
-            src_path = src_edc_datasource + "://" + src_ref["src_zone"] + "/" + source_name
+            src_edc_datasource, src_prefix, src_layer, src_zone = self.get_datasource_ref(src_ref["src_zone"])
+            src_path = src_edc_datasource + "://" + src_prefix + src_ref["src_zone"] + "/" + source_name
         tgt_ref = self.get_dataset_ref("target", target_name)
         if tgt_ref is None:
             tgt_path = "NONE://" + target_name
         else:
-            tgt_edc_datasource = tgt_ref["tgt_zone"].split("/", 4)[2]
-            tgt_path = tgt_edc_datasource + "://" + tgt_ref["tgt_zone"]  + "/" + target_name
+            tgt_edc_datasource, tgt_prefix, tgt_layer, tgt_zone = self.get_datasource_ref(tgt_ref["tgt_zone"])
+            if tgt_zone is None or tgt_zone == "":
+                tgt_path = tgt_edc_datasource + "://" + tgt_prefix + tgt_layer + "/" + target_name
+            else:
+                tgt_path = tgt_edc_datasource + "://" + tgt_prefix + tgt_ref["tgt_zone"]  + "/" + target_name
 
         item = ["core.DataSetDataFlow", "", "", src_path, tgt_path]
         return item
 
+    def get_datasource_ref(self, ref):
+        the_layer = "NO_LAYER"
+        the_zone = "NO_ZONE"
+        the_datasource = "NONE"
+        the_prefix = "FileServer/"
+        splits = ref.split("/", 4)
+        for split in splits:
+            if "_layer" in split:
+                the_layer = split
+            if "_zone" in split:
+                the_zone = split
+        for item in self.resource_items:
+            if item["layer"] == the_layer:
+                the_datasource = item["resource"]
+                the_zone = item["zone"]
+                the_prefix = item["prefix"]
+
+        return the_datasource, the_prefix, the_layer, the_zone
+
     def get_dataset_ref(self, src_or_tgt, dataset_name):
         file = self.find_latest_ref_file(src_or_tgt)
         if file is None:
